@@ -68,15 +68,15 @@ fn get_cooldown_time_per_request(exchange: &str) -> Duration {
         "bitget" => 100,       // 20 requests per 2 seconds
         "bithumb" => 8,        // 135 requests per 1 second for public APIs
         "bitmex" => 2000, // 60 requests per minute on all routes (reduced to 30 when unauthenticated)
-        "bitstamp" => 75, // 8000 requests per 10 minutes
-        "bitz" => 34,     // no more than 30 times within 1 second
-        "bybit" => 20,    // 50 requests per second continuously for 2 minutes
+        "bitstamp" => 30000, // 8000 requests per 10 minutes, but bitstamp orderbook is too big, need to reduce its frequency
+        "bitz" => 34,        // no more than 30 times within 1 second
+        "bybit" => 20,       // 50 requests per second continuously for 2 minutes
         "coinbase_pro" => 100, //  10 requests per second
-        "deribit" => 50,  // 20 requests per second
-        "gate" => 4,      // 300 read operations per IP per second
-        "huobi" => 2,     // 800 times/second for one IP
-        "mxc" => 100,     // 20 times per 2 seconds
-        "okex" => 100,    // 20 requests per 2 seconds
+        "deribit" => 50,     // 20 requests per second
+        "gate" => 4,         // 300 read operations per IP per second
+        "huobi" => 2,        // 800 times/second for one IP
+        "mxc" => 100,        // 20 times per 2 seconds
+        "okex" => 100,       // 20 requests per 2 seconds
         _ => 100,
     };
     Duration::from_millis(millis)
@@ -104,18 +104,6 @@ pub(crate) fn crawl_snapshot(
         None => true,
     };
 
-    let mut real_symbols = if is_empty {
-        if market_type == MarketType::Spot {
-            let spot_symbols = fetch_symbols_retry(exchange, market_type);
-            get_hot_spot_symbols(exchange, &spot_symbols)
-        } else {
-            fetch_symbols_retry(exchange, market_type)
-        }
-    } else {
-        symbols.unwrap().to_vec()
-    };
-    sort_by_cmc_rank(exchange, &mut real_symbols);
-
     let cooldown_time = get_cooldown_time_per_request(exchange);
 
     let mut lock = if exchange == "bitmex"
@@ -148,6 +136,18 @@ pub(crate) fn crawl_snapshot(
         None
     };
     loop {
+        let mut real_symbols = if is_empty {
+            if market_type == MarketType::Spot {
+                let spot_symbols = fetch_symbols_retry(exchange, market_type);
+                get_hot_spot_symbols(exchange, &spot_symbols)
+            } else {
+                fetch_symbols_retry(exchange, market_type)
+            }
+        } else {
+            symbols.unwrap().to_vec()
+        };
+        sort_by_cmc_rank(exchange, &mut real_symbols);
+
         let mut index = 0_usize;
         let mut success_count = 0_u64;
         let mut back_off_factor = 1;
@@ -206,7 +206,7 @@ pub(crate) fn crawl_snapshot(
                 break;
             }
         }
-        std::thread::sleep(Duration::from_secs(5)); // sleep 5 seconds after each round
+        std::thread::sleep(Duration::from_secs(2)); // sleep 2 seconds after each round
     }
 }
 
